==> bootstrap-styled-redux-0.0.3.tgz: package/README.md <==
# bootstrap-styled-redux

`ConnectBootstrapProvider` ReactJS component made for bootstrap-styled and redux.

**Master**

[![build status](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-redux/badges/master/build.svg)](https://module.kopaxgroup.com/styled-components/bootstrap-styled-redux/commits/master)
[![coverage report](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-redux/badges/master/coverage.svg)](https://module.kopaxgroup.com/styled-components/bootstrap-styled-redux/commits/master)

**Dev**

[![build status](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-redux/badges/dev/build.svg)](https://module.kopaxgroup.com/styled-components/bootstrap-styled-redux/commits/dev)
[![coverage report](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-redux/badges/dev/coverage.svg)](https://module.kopaxgroup.com/styled-components/bootstrap-styled-redux/commits/dev)


## Table of Contents

  - [Changelog](#changelog)
  - [Documentation](#documentation)
  - [License](#license)

---

## Changelog

  - View [Changelog](CHANGELOG.md)
  
## Documentation

  - View [Markdown documentation](docs)
  - View bootstrap-styled-redux [HTML documentation](https://bootstrap-styled.kopaxgroup.com.yeutech.com/bootstrap-styled-redux) *(require access)*
  - View rollup-umd [HTML documentation](https://dev-tools.yeutech.com/rollup-umd) *(require access)*

## License

Licensed under the MIT License, Copyright © 2017-present Yeutech Company Limited.

See [LICENSE](LICENSE.md) for more information.

==> bootstrap-styled-redux-0.1.0.tgz: package/README.md <==
# bootstrap-styled-redux

`ConnectBootstrapProvider` ReactJS component made for bootstrap-styled and redux.

**Master**

[![build status](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-redux/badges/master/build.svg)](https://module.kopaxgroup.com/styled-components/bootstrap-styled-redux/commits/master)
[![coverage report](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-redux/badges/master/coverage.svg)](https://module.kopaxgroup.com/styled-components/bootstrap-styled-redux/commits/master)

**Dev**

[![build status](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-redux/badges/dev/build.svg)](https://module.kopaxgroup.com/styled-components/bootstrap-styled-redux/commits/dev)
[![coverage report](https://module.kopaxgroup.com/bootstrap-styled/bootstrap-styled-redux/badges/dev/coverage.svg)](https://module.kopaxgroup.com/styled-components/bootstrap-styled-redux/commits/dev)


## Table of Contents

  - [Changelog](#changelog)
  - [Documentation](#documentation)
  - [License](#license)

---

## Changelog

  - View [Changelog](CHANGELOG.md)
  
## Documentation

  - View [Markdown documentation](docs)
  - View bootstrap-styled-redux [HTML documentation](https://bootstrap-styled.kopaxgroup.com.yeutech.com/bootstrap-styled-redux)
  - View rollup-umd [HTML documentation](https://dev-tools.yeutech.com/rollup-umd) *(require access)*

## License

Licensed under the MIT License, Copyright © 2017-present Yeutech Company Limited.

See [LICENSE](LICENSE.md) for more information.
